﻿using Jypeli;

/// @author Vesa Lappalainen, Antti-Jussi Lakanen
/// @version 2025
///
/// <summary>
/// Piirrellään laatikoita kauniisti.
/// </summary>
public class LaatikotPienenee : Game
{
    /// <summary>
    /// Aliohjelma piirtää ruutuun yhden neliön.
    /// </summary>
    /// <param name="paikka">Neliön vasemman alanurkan koordinaatit.</param>
    /// <param name="sivu">Neliön sivun pituus.</param>
    /// <returns>Neliön oikean ylänurkan koordinaatit.</returns>
    public Vector PiirraLaatikko(Vector paikka, double sivu)
    {
        GameObject laatikko = new GameObject(sivu, sivu);
        Vector siirto = new Vector(sivu / 2, sivu / 2);
        laatikko.Position = paikka + siirto; // laatikon keskipisteeseen
        Add(laatikko);
        return paikka + 2 * siirto; // vasen alakulma -> oikea yläkulma
    }

    /// <summary>
    /// Kutsutaan PiirraLaatikkoa muutaman kerran.
    /// </summary>
    public override void Begin()
    {
        Camera.ZoomToLevel();
        Level.Background.Color = Color.DarkCyan;
        const int N = 8; // laatikoita yhteensä
        const double SIVUN_PITUUS = 100; // ekan laatikon sivun pituus
        Vector v = Vector.Zero;

        for (int i = 0; i < N; i++)
        {
            // Mieti, miksi viimeiseksi argumentiksi ei kävisi: 
            // (N-i) / N * SIVUN_PITUUS
            v = PiirraLaatikko(v, 1.0 * (N - i) / N * SIVUN_PITUUS );
        }

        Camera.ZoomToAllObjects(100);
    }
}